@@ -29,6 +29,12 @@ History
     * 'cname' can be list of names in 'get_color', Apr 2022, Matthias Cuntz
     * Register ufz colors only once, Apr 2022, Matthias Cuntz
     * Added print_colors, Apr 2022, Matthias Cuntz
+    * Use matplotlib.colormaps.get_cmap instead of deprecated
+      matplotlib.cm.get_cmap, Dec 2022, Matthias Cuntz
+    * Use matplotlib.colormaps[name] instead of
+      matplotlib.colormaps.get_cmap(name) to work with matplotlib < v3.6,
+      Jan 2023, Matthias Cuntz
+    * Do not set_bad() for sron palettes, Jan 2023, Matthias Cuntz
 
 """
 
@@ -192,8 +198,8 @@ def print_colors(collection=''):
         print('       ', list(ll))
 
 
-def get_cmap(palette, ncol=0, offset=0, upper=1, as_cmap=False,
-             reverse=False, grey=False, order=None):
+def get_cmap(palette, ncol=0, offset=0, upper=1,
+             reverse=False, grey=False, order=None, as_cmap=False):
     """
     Get colors of defined palettes or continuous colormaps
 
@@ -221,6 +227,9 @@ def get_cmap(palette, ncol=0, offset=0, upper=1, as_cmap=False,
         Order colors by 'hue', 'saturation', or 'value'.
         This is done before *reverse* and *grey*
         (default: order from color sources).
+    as_cmap : bool, optional
+        If True, returns matplotlib.colors.Colormap
+        instead of list of RGB tuples
 
     Returns
     -------
@@ -283,7 +292,7 @@ def get_cmap(palette, ncol=0, offset=0, upper=1, as_cmap=False,
 
     found_palette = False
     nosubsample = False
-    miss = None
+    # miss = None
 
     if not found_palette:
         for bb in pyjams_collections:
@@ -303,7 +312,7 @@ def get_cmap(palette, ncol=0, offset=0, upper=1, as_cmap=False,
                 elif bb == 'sron_colormaps':
                     colors = [ mpl.colors.colorConverter.to_rgb(i)
                                for i in dd[palette][0] ]
-                    miss = mpl.colors.colorConverter.to_rgb(dd[palette][1])
+                    # miss = mpl.colors.colorConverter.to_rgb(dd[palette][1])
                 elif bb == 'sron_functions':
                     nosubsample = True
                     if ncol == 0:
@@ -313,7 +322,7 @@ def get_cmap(palette, ncol=0, offset=0, upper=1, as_cmap=False,
                     cols = dd[palette](ncol1)
                     colors = [ mpl.colors.colorConverter.to_rgb(i)
                                for i in cols[0] ]
-                    miss = mpl.colors.colorConverter.to_rgb(cols[1])
+                    # miss = mpl.colors.colorConverter.to_rgb(cols[1])
 
     if not found_palette:
         for bb in sron2012_collections:
@@ -365,7 +374,9 @@ def get_cmap(palette, ncol=0, offset=0, upper=1, as_cmap=False,
         mplmaps = [ i for i in amplmaps if not i.endswith('_r') ]
         if palette in mplmaps:
             found_palette = True
-            cmap = mpl.cm.get_cmap(palette)
+            # cmap = mpl.cm.get_cmap(palette)
+            # cmap = mpl.colormaps.get_cmap(palette)
+            cmap = mpl.colormaps[palette]
             try:
                 # mpl.colors.ListedColormap
                 colors = cmap.colors
@@ -377,7 +388,9 @@ def get_cmap(palette, ncol=0, offset=0, upper=1, as_cmap=False,
             if palette.lower() in lmplmaps:
                 found_palette = True
                 ipalette = lmplmaps.index(palette.lower())
-                cmap = mpl.cm.get_cmap(mplmaps[ipalette])
+                # cmap = mpl.cm.get_cmap(mplmaps[ipalette])
+                # cmap = mpl.colormaps.get_cmap(mplmaps[ipalette])
+                cmap = mpl.colormaps[mplmaps[ipalette]]
                 try:
                     # mpl.colors.ListedColormap
                     colors = cmap.colors
@@ -423,9 +436,9 @@ def get_cmap(palette, ncol=0, offset=0, upper=1, as_cmap=False,
 
     if as_cmap:
         colors = mpl.colors.ListedColormap(colors)
-        if mpl.__version__ > '3.4.0':
-            if miss is not None:
-                colors.set_bad(miss)
+        # if mpl.__version__ > '3.4.0':
+        #     if miss is not None:
+        #         colors.set_bad(miss)
 
     return colors
 
