@@ -31,6 +31,8 @@ History
     * undef=None by default, Jun 2022, Matthias Cuntz
     * Refine using undef=None with numpy.array and list,
       Jun 2022, Matthias Cuntz
+    * Assure array is not 0d-array, Jun 2022, Matthias Cuntz
+    * Correct treating of undef if two arrays given, Jan 2023, Matthias Cuntz
 
 """
 from collections.abc import Iterable
@@ -122,9 +124,29 @@ def array2input(outin, inp, inp2=None, undef=None):
 
     """
     if inp2 is not None:
-        if ( (not isinstance(inp, Iterable)) or
-             isinstance(inp2, np.ma.MaskedArray) ):
-            return array2input(outin, inp2, undef=undef)
+        if not isinstance(inp, Iterable):
+            if isundef(inp, undef):
+                outout = undef
+            else:
+                outout = outin
+            return array2input(outout, inp2, undef=undef)
+        elif isinstance(inp2, np.ma.MaskedArray):
+            if isinstance(inp, np.ma.MaskedArray):
+                outout = np.ma.where(isundef(inp, undef),
+                                     undef, outin).filled(undef)
+            elif isinstance(inp, str):
+                outout = np.where(isundef(np.array([inp]), undef),
+                                  undef, outin)
+            else:
+                outout = np.where(isundef(np.array(inp), undef), undef, outin)
+            return array2input(outout, inp2, undef=undef)
+        else:
+            if isinstance(inp2, str):
+                outout = np.where(isundef(np.array([inp2]), undef),
+                                  undef, outin)
+            else:
+                outout = np.where(isundef(np.array(inp2), undef), undef, outin)
+            return array2input(outout, inp, undef=undef)
 
     if isinstance(inp, Iterable):
         if isinstance(inp, np.ma.MaskedArray):
@@ -173,6 +195,7 @@ def array2input(outin, inp, inp2=None, undef=None):
                 # unknown iterables so no cover
                 pass
     else:
+        # scalar / object
         if isundef(inp, undef):
             outout = undef
         else:
@@ -180,7 +203,10 @@ def array2input(outin, inp, inp2=None, undef=None):
                 outout = type(inp)(outin)
             except:  # pragma: no cover
                 # unknown iterables so no cover
-                outout = outin
+                if np.size(outin) == 1:
+                    outout = outin[0]
+                else:
+                    outout = outin
 
     return outout
 
@@ -233,8 +259,8 @@ def input2array(inp, undef=None, default=1):
             out = np.array(inp)
             out = np.where(isundef(out, undef), default, out)
     else:
-        # scalar
-        out = np.array(default) if isundef(inp, undef) else np.array(inp)
+        # scalar / object
+        out = np.array([default]) if isundef(inp, undef) else np.array([inp])
 
     return out
 
