@@ -42,7 +42,7 @@ The simplest way to use mcPlot is to extend the class:
 
            larr = sub.plot(self.dat)
            plt.setp(larr[-1], linestyle='-', linewidth=self.lwidth,
-                    marker=None, color=self.lcol1)
+                    marker='', color=self.lcol1)
 
            self.plot_save(fig)
 
@@ -56,7 +56,7 @@ The simplest way to use mcPlot is to extend the class:
 
            larr = sub.plot(2*self.dat)
            plt.setp(larr[-1], linestyle='-', linewidth=self.lwidth,
-                    marker=None, color=self.lcols[-1])
+                    marker='', color=self.lcols[-1])
 
            self.plot_save(fig)
 
@@ -93,6 +93,9 @@ History
     * Add **kwargs to plot_save, May 2022, Matthias Cuntz
     * Add self.transparent to pdf output in plot_save, May 2022, Matthias Cuntz
     * Add --transparent as a standard option, May 2022, Matthias Cuntz
+    * Add left, bottom, top to standard layout options,
+      Jul 2022, Matthias Cuntz
+    * Add --dpi as a standard option, Jan 2023, Matthias Cuntz
 
 """
 import numpy as np
@@ -150,7 +153,7 @@ class mcPlot(object):
         such as plot type, filename, etc. If extra arguments are needed,
         one should copy this routine into the extending class and adapt
         it to its needs, keeping the existing optional arguments.
-    plot_end() or plot_stop() or or plot_close() or end() or stop()
+    plot_end() or plot_stop() or plot_close() or end() or stop()
         Finish, closing opened output files.
     plot_save(fig, **kwargs)
         Save, close or show `figure`.
@@ -208,7 +211,7 @@ class mcPlot(object):
 
                larr = sub.plot(self.dat)
                plt.setp(larr[-1], linestyle='-', linewidth=self.lwidth,
-                        marker=None, color=self.lcol1)
+                        marker='', color=self.lcol1)
 
                self.plot_save(fig)
 
@@ -222,7 +225,7 @@ class mcPlot(object):
 
                larr = sub.plot(2*self.dat)
                plt.setp(larr[-1], linestyle='-', linewidth=self.lwidth,
-                        marker=None, color=self.lcols[-1])
+                        marker='', color=self.lcols[-1])
 
                self.plot_save(fig)
 
@@ -312,13 +315,16 @@ class mcPlot(object):
              -t outtype, --type outtype
                                    Output type is pdf, png, html, d3, or plotly
                                    (default: open screen windows).
-             --transparent         Transparent figure background
-                                   (default: black or white).
              -u, --usetex          Use LaTeX to render text in pdf, png and
                                    html.
              -w, --white           White lines on transparent or black
                                    background; default: black lines on
                                    transparent or white background.
+             --dpi number          Dots Per inch (DPI) for non-vector output
+                                   types or rasterized maps in vector output
+                                   (default: 300).
+             --transparent         Transparent figure background
+                                   (default: black or white).
 
         Examples
         --------
@@ -346,7 +352,8 @@ class mcPlot(object):
         transparent = False
         usetex   = False
         dowhite  = False
-        parser   = argparse.ArgumentParser(
+        dpi      = 300
+        parser = argparse.ArgumentParser(
             formatter_class=argparse.RawDescriptionHelpFormatter,
             description=idesc)
         default = _filebase(os.path.basename(__file__))
@@ -363,9 +370,6 @@ class mcPlot(object):
                 ' (default: open screen windows).')
         parser.add_argument('-t', '--type', action='store', default=outtype,
                             dest='outtype', metavar='outtype', help=hstr)
-        hstr = ('Transparent figure background (default: black or white).')
-        parser.add_argument('--transparent', action='store_true',
-                            default=transparent, dest='transparent', help=hstr)
         hstr = 'Use LaTeX to render text in pdf, png and html.'
         parser.add_argument('-u', '--usetex', action='store_true',
                             default=usetex, dest='usetex', help=hstr)
@@ -375,6 +379,13 @@ class mcPlot(object):
                             default=dowhite, dest='dowhite', help=hstr)
         parser.add_argument('cargs', nargs='*', default=None,
                             metavar='args', help=iargstr)
+        hstr = ('Dots Per inch (DPI) for non-vector output types or rasterized'
+                ' maps in vector output (default: 300).')
+        parser.add_argument('--dpi', action='store', default=dpi, type=int,
+                            dest='dpi', metavar='number', help=hstr)
+        hstr = ('Transparent figure background (default: black or white).')
+        parser.add_argument('--transparent', action='store_true',
+                            default=transparent, dest='transparent', help=hstr)
 
         args = parser.parse_args()
 
@@ -382,9 +393,10 @@ class mcPlot(object):
         self.plotname    = args.plotname
         self.serif       = args.serif
         self.outtype     = args.outtype
-        self.transparent = args.transparent
         self.usetex      = args.usetex
         self.dowhite     = args.dowhite
+        self.dpi         = args.dpi
+        self.transparent = args.transparent
 
         del parser, args
 
@@ -412,12 +424,18 @@ class mcPlot(object):
              - number of rows of subplots per figure
            * - self.ncol
              - number of columns of subplots per figure
-           * - self.hspace
-             - x-space between subplots
-           * - self.vspace
-             - y-space between subplots
+           * - self.left
+             - left space on page
            * - self.right
              - right space on page
+           * - self.bottom
+             - lower bottom space on page
+           * - self.top
+             - upper top space on page
+           * - self.hspace
+             - (horizontal) x-space between subplots
+           * - self.vspace
+             - (vertical) y-space between subplots
            * - self.textsize
              - standard text size
            * - self.dxabc
@@ -508,9 +526,12 @@ class mcPlot(object):
         # layout and spaces
         self.nrow     = 3     # # of rows of subplots per figure
         self.ncol     = 2     # # of columns of subplots per figure
-        self.hspace   = 0.10  # x-space between subplots
-        self.vspace   = 0.05  # y-space between subplots
+        self.left     = 0.125  # left space on page
         self.right    = 0.9   # right space on page
+        self.bottom   = 0.1   # lower space on page
+        self.top      = 0.9   # upper space on page
+        self.hspace   = 0.1   # x-space between subplots
+        self.vspace   = 0.1   # y-space between subplots
         self.textsize = 12    # standard text size
         self.dxabc    = 0.90  # % of (max-min) shift to the right
                               # of left y-axis for a,b,c,... labels
@@ -575,7 +596,7 @@ class mcPlot(object):
         self.frameon    = False  # if True, draw a frame around the legend.
                                  # If None, use rc
         # png
-        self.dpi         = 300
+        # self.dpi         = 300
         self.bbox_inches = 'tight'
         self.pad_inches  = 0.035
 
@@ -610,12 +631,12 @@ class mcPlot(object):
 
         tarr = ['sin']
         larr = sub.plot(xx, yy1)
-        plt.setp(larr[-1], linestyle='-', linewidth=self.lwidth, marker=None,
+        plt.setp(larr[-1], linestyle='-', linewidth=self.lwidth, marker='',
                  color=self.lcols[0])
 
         tarr += ['cos']
         larr += sub.plot(xx, yy2)
-        plt.setp(larr[-1], linestyle='-', linewidth=self.lwidth, marker=None,
+        plt.setp(larr[-1], linestyle='-', linewidth=self.lwidth, marker='',
                  color=self.lcols[-3])
 
         if xlab != '':
