@@ -142,10 +142,10 @@ class TestNcio(unittest.TestCase):
             os.remove(ofile)
 
     def test_get_fill_value_for_dtype(self):
+        import pytest
         import numpy as np
         import netCDF4 as nc
         import pyjams.ncio as ncio
-        import warnings
 
         itypes = [np.int8, np.int16, np.int32, np.int64,
                   np.uint8, np.uint16, np.uint32, np.uint64,
@@ -160,6 +160,15 @@ class TestNcio(unittest.TestCase):
             fsoll = nc.default_fillvals[otypes[ii]]
             assert fout == fsoll
 
+    def test_get_fill_value_for_float128(self):
+        import sys
+        import warnings
+        import pytest
+        import numpy as np
+        import pyjams.ncio as ncio
+
+        if sys.platform.startswith("win"):
+            pytest.skip("skipping tests that require float128 on windows")
         # warning unknown type
         with warnings.catch_warnings(record=True) as w:
             nn = np.float128
